==> tetzle_2.2.3.orig.tar.gz: tetzle-2.2.3/translations/tetzle_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Resim Aç</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Eğimli Köşeler</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Alt gölgeler</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Renkler</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Arka Plan:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Gölge:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Vurgulama:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Kayıp resim.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Lütfen Bekleyin</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Resim yükleniyor...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Yap-boz oluşturuluyor...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Parçalar oluşturuluyor...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Yap-boz yükleniyor...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Bilinmeyen veri biçimi</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Blinmeyen  &apos;%1&apos; ögesi</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>XML dosyası ayrıştırma hatası.⏎ ⏎ %1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Parçalar yükleniyor...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Parçalar alınıyor...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Parçalar yerleştiriliyor...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Oyun Seç</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Mevcut Oyunlar</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Resim Seçenekleri</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiketler:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Resim Ekle</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Resim Kaldır</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Resim Seçenekleri</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 parça</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Resimler kopyalanıyor...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal Et</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Seçilmiş resim kaldırılsın mı?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Seçilmiş resim kaldırılsın mı?⏎ ⏎ Bu resmi kullanan kayıtlı oyunlar da kaldırılacaktır.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 parça %2 %3% tamamlandı</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Oyunu Sil</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Seçilmiş oyun silinsin mi?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Küçük Resim</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Etiket Ekle</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Etiketi Kaldır</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Etiketlenmemiş</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Tüm Resimler</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Başlıksız %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Seçilmiş etiket kaldırılsın mı?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Bu adda bir etiket zaten var.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Parçaları Geri Getir</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Seç...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Yakınlaş</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uzaklaş</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;En Uygun</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>&amp;Küçük Resmi Göster</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Sekme</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Görünüm...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Dil...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kontroller...</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Al:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Sol Tıklama ya da Boşluk</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Bırak:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Seç:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Sol Sürükleme</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Döndür:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Sağ Tıklama, Ctrl + Sol Tıklama ya da R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Yap-bozu Sürükle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Orta Tıklama, Shift + Sol Tıklama ya da Oklar</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Yap-boz Yakınlaş/Uzaklaş:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Tekerleği çevir ya da +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;İmleci Hareket Ettir:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Fare ya da W, A, S, D</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Tetzle Hakkında</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Tetris benzeri parçalı bir yap-boz oyunu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Telif hakları saklıdır &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>OpenGL sürümünü seçin.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>sürüm</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Oyun seç iletişim kutusuna eklenecek resimler.</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Resim Aç</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Eğimli Köşeler</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Alt gölgeler</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Renkler</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Arka Plan:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Gölge:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Vurgulama:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Kayıp resim.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Lütfen Bekleyin</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Resim yükleniyor...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Yap-boz oluşturuluyor...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Parçalar oluşturuluyor...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Yap-boz yükleniyor...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Bilinmeyen veri biçimi</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Blinmeyen  &apos;%1&apos; ögesi</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>XML dosyası ayrıştırma hatası.⏎ ⏎ %1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Parçalar yükleniyor...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Parçalar alınıyor...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Parçalar yerleştiriliyor...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Oyun Seç</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Mevcut Oyunlar</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Resim Seçenekleri</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiketler:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Resim Ekle</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Resim Kaldır</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Resim Seçenekleri</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 parça</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Resimler kopyalanıyor...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal Et</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 parça %2 %3% tamamlandı</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Oyunu Sil</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Seçilmiş oyun silinsin mi?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Küçük Resim</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Etiket Ekle</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Etiketi Kaldır</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Etiketlenmemiş</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Tüm Resimler</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Başlıksız %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Seçilmiş etiket kaldırılsın mı?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Bu adda bir etiket zaten var.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Parçaları Geri Getir</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Seç...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Yakınlaş</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uzaklaş</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;En Uygun</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>&amp;Küçük Resmi Göster</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Sekme</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Görünüm...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Dil...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kontroller...</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Al:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Sol Tıklama ya da Boşluk</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Bırak:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Seç:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Sol Sürükleme</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Parçaları Döndür:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Sağ Tıklama, Ctrl + Sol Tıklama ya da R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Yap-bozu Sürükle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Orta Tıklama, Shift + Sol Tıklama ya da Oklar</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Yap-boz Yakınlaş/Uzaklaş:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Tekerleği çevir ya da +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;İmleci Hareket Ettir:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Fare ya da W, A, S, D</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Tetzle Hakkında</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Tetris benzeri parçalı bir yap-boz oyunu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Telif hakları saklıdır &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Oyun seç iletişim kutusuna eklenecek resimler.</translation>
    </message>
</context>
</TS>
